Index: include/gpu/GrContext.h |
diff --git a/include/gpu/GrContext.h b/include/gpu/GrContext.h |
index 86c9fa925ffba83e3a9ee33c7dc9306f5c9c6e35..4e2546b6e22eb1975cde146e455aa2e6ac587d6f 100644 |
--- a/include/gpu/GrContext.h |
+++ b/include/gpu/GrContext.h |
@@ -27,7 +27,6 @@ struct GrContextOptions; |
class GrContextThreadSafeProxy; |
class GrDrawingManager; |
class GrDrawContext; |
-class GrDrawTarget; |
class GrFragmentProcessor; |
class GrGpu; |
class GrIndexBuffer; |
@@ -354,8 +353,8 @@ public: |
const GrResourceProvider* resourceProvider() const { return fResourceProvider; } |
GrResourceCache* getResourceCache() { return fResourceCache; } |
- // Called by tests that draw directly to the context via GrDrawTarget |
- void getTestTarget(GrTestTarget*, GrRenderTarget* rt); |
+ // Called by tests that draw directly to the context via GrDrawContext |
+ void getTestTarget(GrTestTarget*, sk_sp<GrDrawContext>); |
/** Reset GPU stats */ |
void resetGpuStats() const ; |